AgeHeader class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stanzas List<AgeStanza>
no setter
withoutMac Future<String>
no setter

Methods

checkMac(Uint8List symmetricFileKey) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(List<AgeStanza> stanzas, Uint8List symmetricFileKey) Future<AgeHeader>
headerWithoutMac(List<AgeStanza> stanzas) Future<String>
parse(String header, {PassphraseProvider passphraseProvider = const PassphraseProvider()}) Future<AgeHeader>
parseContent(AgeStream content, {PassphraseProvider passphraseProvider = const PassphraseProvider()}) Future<AgeHeader>