AgePlugin class abstract

Constructors

AgePlugin()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPassphraseStanza(List<int> symmetricFileKey, List<int> salt, {PassphraseProvider passphraseProvider, int workFactor}) Future<AgeStanza?>
createStanza(AgeRecipient recipient, List<int> symmetricFileKey, [KeyPair? ephemeralKeyPair]) Future<AgeStanza?>
identityToKeyPair(AgeIdentity identity) Future<AgeKeyPair?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseStanza(List<String> arguments, List<int> body, {PassphraseProvider passphraseProvider}) Future<AgeStanza?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convertIdentityToKeyPair(AgeIdentity identity) Future<AgeKeyPair>
firstPlugin<T>(Future<T?> func(AgePlugin plugin)) Future<T>
firstPluginSync<T>(T? func(AgePlugin plugin)) → T
passphraseStanzaCreate(List<int> symmetricFileKey, List<int> salt, PassphraseProvider passphraseProvider, int workFactor) Future<AgeStanza>
registerPlugin(AgePlugin p) → void
stanzaCreate(AgeRecipient recipient, List<int> symmetricFileKey, [SimpleKeyPair? ephemeralKeyPair]) Future<AgeStanza>
stanzaParse(List<String> arguments, List<int> body, PassphraseProvider passphraseProvider) Future<AgeStanza>